@@ -45,6 +45,7 @@ impl LanguageServer for Backend {
                 }),
                 ..ServerCapabilities::default()
             },
+            ..Default::default()
         })
     }
 
@@ -55,7 +56,7 @@ impl LanguageServer for Backend {
     async fn execute_command(&self, params: ExecuteCommandParams) -> Result<Option<Value>> {
         if params.command == "custom.notification" {
             self.client
-                .send_custom_notification::<CustomNotification>(CustomNotificationParams::new(
+                .send_notification::<CustomNotification>(CustomNotificationParams::new(
                     "Hello", "Message",
                 ))
                 .await;
@@ -74,14 +75,15 @@ impl LanguageServer for Backend {
 
 #[tokio::main]
 async fn main() {
+    #[cfg(feature = "runtime-agnostic")]
+    use tokio_util::compat::{TokioAsyncReadCompatExt, TokioAsyncWriteCompatExt};
+
     env_logger::init();
 
-    let stdin = tokio::io::stdin();
-    let stdout = tokio::io::stdout();
+    let (stdin, stdout) = (tokio::io::stdin(), tokio::io::stdout());
+    #[cfg(feature = "runtime-agnostic")]
+    let (stdin, stdout) = (stdin.compat(), stdout.compat_write());
 
-    let (service, messages) = LspService::new(|client| Backend { client });
-    Server::new(stdin, stdout)
-        .interleave(messages)
-        .serve(service)
-        .await;
+    let (service, socket) = LspService::new(|client| Backend { client });
+    Server::new(stdin, stdout, socket).serve(service).await;
 }
