@@ -23,6 +23,7 @@ impl LanguageServer for Backend {
                     trigger_characters: Some(vec![".".to_string()]),
                     work_done_progress_options: Default::default(),
                     all_commit_characters: None,
+                    ..Default::default()
                 }),
                 execute_command_provider: Some(ExecuteCommandOptions {
                     commands: vec!["dummy.do_something".to_string()],
@@ -37,6 +38,7 @@ impl LanguageServer for Backend {
                 }),
                 ..ServerCapabilities::default()
             },
+            ..Default::default()
         })
     }
 
@@ -116,15 +118,17 @@ impl LanguageServer for Backend {
 
 #[tokio::main]
 async fn main() {
+    #[cfg(feature = "runtime-agnostic")]
+    use tokio_util::compat::{TokioAsyncReadCompatExt, TokioAsyncWriteCompatExt};
+
     env_logger::init();
 
     let listener = TcpListener::bind("127.0.0.1:9257").await.unwrap();
     let (stream, _) = listener.accept().await.unwrap();
     let (read, write) = tokio::io::split(stream);
+    #[cfg(feature = "runtime-agnostic")]
+    let (read, write) = (read.compat(), write.compat_write());
 
-    let (service, messages) = LspService::new(|client| Backend { client });
-    Server::new(read, write)
-        .interleave(messages)
-        .serve(service)
-        .await;
+    let (service, socket) = LspService::new(|client| Backend { client });
+    Server::new(read, write, socket).serve(service).await;
 }
