@@ -17,7 +17,14 @@
 //! #[tower_lsp::async_trait]
 //! impl LanguageServer for Backend {
 //!     async fn initialize(&self, _: InitializeParams) -> Result<InitializeResult> {
-//!         Ok(InitializeResult::default())
+//!         Ok(InitializeResult {
+//!             capabilities: ServerCapabilities {
+//!                 hover_provider: Some(HoverProviderCapability::Simple(true)),
+//!                 completion_provider: Some(CompletionOptions::default()),
+//!                 ..Default::default()
+//!             },
+//!             ..Default::default()
+//!         })
 //!     }
 //!
 //!     async fn initialized(&self, _: InitializedParams) {
@@ -49,18 +56,18 @@
 //!
 //! #[tokio::main]
 //! async fn main() {
+//! #   #[cfg(feature = "runtime-agnostic")]
+//! #   use tokio_util::compat::{TokioAsyncReadCompatExt, TokioAsyncWriteCompatExt};
 //! #   use std::io::Cursor;
 //!     let stdin = tokio::io::stdin();
-//! #   let message = r#"{"jsonrpc":"2.0","method":"exit"}"#;
-//! #   let stdin = Cursor::new(format!("Content-Length: {}\r\n\r\n{}", message.len(), message).into_bytes());
 //!     let stdout = tokio::io::stdout();
-//! #   let stdout = Cursor::new(Vec::new());
+//! #   let message = r#"{"jsonrpc":"2.0","method":"exit"}"#;
+//! #   let (stdin, stdout) = (Cursor::new(format!("Content-Length: {}\r\n\r\n{}", message.len(), message).into_bytes()), Cursor::new(Vec::new()));
+//! #   #[cfg(feature = "runtime-agnostic")]
+//! #   let (stdin, stdout) = (stdin.compat(), stdout.compat_write());
 //!
-//!     let (service, messages) = LspService::new(|client| Backend { client });
-//!     Server::new(stdin, stdout)
-//!         .interleave(messages)
-//!         .serve(service)
-//!         .await;
+//!     let (service, socket) = LspService::new(|client| Backend { client });
+//!     Server::new(stdin, stdout, socket).serve(service).await;
 //! }
 //! ```
 
@@ -70,15 +77,11 @@
 
 pub extern crate lsp_types;
 
-pub use self::client::Client;
-pub use self::service::{ExitedError, LspService, MessageStream};
-pub use self::transport::Server;
-
 /// A re-export of [`async-trait`](https://docs.rs/async-trait) for convenience.
 pub use async_trait::async_trait;
 
-use std::fmt::{self, Debug, Formatter};
-use std::sync::atomic::{AtomicUsize, Ordering};
+pub use self::service::{Client, ClientSocket, ExitedError, LspService, LspServiceBuilder};
+pub use self::transport::{Loopback, Server};
 
 use auto_impl::auto_impl;
 use log::{error, warn};
@@ -94,7 +97,6 @@ use self::jsonrpc::{Error, Result};
 
 pub mod jsonrpc;
 
-mod client;
 mod codec;
 mod service;
 mod transport;
@@ -177,7 +179,7 @@ pub trait LanguageServer: Send + Sync + 'static {
     ///
     /// It is recommended that servers register for these file events using the registration
     /// mechanism. This can be done here or in the [`initialized`](LanguageServer::initialized)
-    /// method using [`Client::register_capability`].
+    /// method using [`Client::register_capability`](crate::Client::register_capability).
     ///
     /// [`workspace/didChangeWatchedFiles`]: https://microsoft.github.io/language-server-protocol/specification#workspace_didChangeConfiguration
     #[rpc(name = "workspace/didChangeWatchedFiles")]
@@ -1065,51 +1067,3 @@ fn _assert_object_safe() {
     fn assert_impl<T: LanguageServer>() {}
     assert_impl::<Box<dyn LanguageServer>>();
 }
-
-/// Atomic value which represents the current state of the server.
-struct ServerState(AtomicUsize);
-
-impl ServerState {
-    #[inline]
-    const fn new() -> Self {
-        ServerState(AtomicUsize::new(State::Uninitialized as usize))
-    }
-
-    #[inline]
-    fn set(&self, state: State) {
-        self.0.store(state as usize, Ordering::SeqCst);
-    }
-
-    #[inline]
-    fn get(&self) -> State {
-        match self.0.load(Ordering::SeqCst) {
-            0 => State::Uninitialized,
-            1 => State::Initializing,
-            2 => State::Initialized,
-            3 => State::ShutDown,
-            4 => State::Exited,
-            _ => unreachable!(),
-        }
-    }
-}
-
-impl Debug for ServerState {
-    fn fmt(&self, f: &mut Formatter) -> fmt::Result {
-        self.get().fmt(f)
-    }
-}
-
-/// A list of possible states the language server can be in.
-#[derive(Clone, Copy, Debug, PartialEq)]
-enum State {
-    /// Server has not received an `initialize` request.
-    Uninitialized = 0,
-    /// Server received an `initialize` request, but has not yet responded.
-    Initializing = 1,
-    /// Server received and responded success to an `initialize` request.
-    Initialized = 2,
-    /// Server received a `shutdown` request.
-    ShutDown = 3,
-    /// Server received an `exit` notification.
-    Exited = 4,
-}
